@@ -1,9 +1,12 @@
 from collections.abc import Iterator
 
+from pydantic import validate_call
+
 from albert.collections.base import BaseCollection
 from albert.core.logging import logger
 from albert.core.pagination import AlbertPaginator, PaginationMode
 from albert.core.session import AlbertSession
+from albert.core.shared.identifiers import CompanyId
 from albert.exceptions import AlbertException
 from albert.resources.companies import Company
 
@@ -91,7 +94,8 @@ class CompanyCollection(BaseCollection):
         companies = self.get_by_name(name=name, exact_match=exact_match)
         return bool(companies)
 
-    def get_by_id(self, *, id: str) -> Company:
+    @validate_call
+    def get_by_id(self, *, id: CompanyId) -> Company:
         """
         Get a company by its ID.
 
@@ -174,7 +178,8 @@ class CompanyCollection(BaseCollection):
         else:
             return self.create(company=company)
 
-    def delete(self, *, id: str) -> None:
+    @validate_call
+    def delete(self, *, id: CompanyId) -> None:
         """Deletes a company entity.
 
         Parameters
