@@ -201,7 +201,9 @@ class InventoryCollection(BaseCollection):
             self.base_path,
             json=inventory_item.model_dump(by_alias=True, exclude_none=True, mode="json"),
         )
-        return InventoryItem(**response.json())
+
+        # ACL is populated after the create response is sent by the API.
+        return self.get_by_id(id=response.json()["albertId"])
 
     @validate_call
     def get_by_id(self, *, id: InventoryId) -> InventoryItem:
@@ -744,13 +746,22 @@ class InventoryCollection(BaseCollection):
                             "operation": "add",
                             "attribute": "casId",
                             "newValue": new_lookup[id].id,
+                            "entityId": new_lookup[id].id,
                             "max": new_lookup[id].max,
                             "min": new_lookup[id].min,
-                            "inventoryValue": new_lookup[id].target,
                             "casCategory": new_lookup[id].cas_category,
                         }
                         add_payload = {k: v for k, v in add_payload.items() if v is not None}
                         payload["data"].append(add_payload)
+                        if new_lookup[id].target:
+                            payload["data"].append(
+                                {
+                                    "operation": "add",
+                                    "attribute": "inventoryValue",
+                                    "newValue": new_lookup[id].target,
+                                    "entityId": new_lookup[id].id,
+                                }
+                            )
                     for id in to_del:
                         payload["data"].append(
                             {
