@@ -1,6 +1,7 @@
 from pydantic import Field
 
-from albert.resources.base import BaseResource, MetadataItem
+from albert.core.shared.models.base import BaseResource
+from albert.core.shared.types import MetadataItem
 
 
 class DataColumn(BaseResource):
