@@ -8,10 +8,16 @@ def test_get_by_id(client: Albert, seeded_btdataset: BTDataset):
     assert fetched_dataset.id == seeded_btdataset.id
 
 
-def test_list_by_user(client: Albert, static_user: User):
-    dataset = next(client.btdatasets.list(created_by=static_user.id), None)
-    assert dataset is not None
-    assert dataset.created.by == static_user.id
+def test_get_all_by_user(client: Albert, static_user: User):
+    results = list(client.btdatasets.get_all(created_by=static_user.id, max_items=10))
+    assert results, "No datasets returned for the user"
+    for dataset in results:
+        assert dataset.created.by == static_user.id
+
+
+def test_get_all_by_name(client: Albert, seeded_btdataset: BTDataset):
+    results = list(client.btdatasets.get_all(name=seeded_btdataset.name, max_items=10))
+    assert any(ds.id == seeded_btdataset.id for ds in results), "Expected dataset not found"
 
 
 def test_update(client: Albert, seeded_btdataset: BTDataset):
