@@ -2,9 +2,9 @@ from albert import Albert
 from albert.resources.workflows import Workflow
 
 
-def test_basic_list(client: Albert, seeded_workflows: list[Workflow]):
-    for wf in client.workflows.list():
-        assert isinstance(wf, Workflow)
+def test_workflow_get_all_with_pagination(client: Albert, seeded_workflows: list[Workflow]):
+    for x in list(client.workflows.get_all(max_items=10)):
+        assert isinstance(x, Workflow)
 
 
 def test_get_by_id(client: Albert, seeded_workflows: list[Workflow]):
