@@ -1,9 +1,10 @@
 from uuid import uuid4
 
-from albert.resources.base import EntityLink, SecurityClass
+from albert.core.shared.enums import SecurityClass
+from albert.core.shared.models.base import EntityLink
 from albert.resources.btdataset import BTDataset
 from albert.resources.btinsight import BTInsight, BTInsightCategory
-from albert.resources.btmodel import BTModel, BTModelCategory, BTModelSession, BTModelState
+from albert.resources.btmodel import BTModel, BTModelSession, BTModelSessionCategory, BTModelState
 from albert.resources.cas import Cas, CasCategory
 from albert.resources.companies import Company
 from albert.resources.custom_fields import (
@@ -45,7 +46,15 @@ from albert.resources.notebooks import (
     TableContent,
 )
 from albert.resources.notes import Note
-from albert.resources.parameter_groups import ParameterGroup, ParameterValue, PGType
+from albert.resources.parameter_groups import (
+    DataType,
+    EnumValidationValue,
+    Operator,
+    ParameterGroup,
+    ParameterValue,
+    PGType,
+    ValueValidation,
+)
 from albert.resources.parameters import Parameter, ParameterCategory
 from albert.resources.pricings import Pricing
 from albert.resources.projects import (
@@ -53,6 +62,7 @@ from albert.resources.projects import (
     Project,
     ProjectClass,
 )
+from albert.resources.reports import FullAnalyticalReport
 from albert.resources.storage_locations import StorageLocation
 from albert.resources.tags import Tag
 from albert.resources.tasks import (
@@ -61,9 +71,9 @@ from albert.resources.tasks import (
     BatchTask,
     Block,
     GeneralTask,
-    InventoryInformation,
     PropertyTask,
     TaskCategory,
+    TaskInventoryInformation,
     TaskPriority,
 )
 from albert.resources.units import Unit, UnitCategory
@@ -89,6 +99,7 @@ def generate_custom_fields() -> list[CustomField]:
         ServiceType.TASKS,
         ServiceType.USERS,
         ServiceType.PARAMETER_GROUPS,
+        ServiceType.CAS,
     ]
 
     seeds = []
@@ -144,7 +155,11 @@ def generate_list_item_seeds(seeded_custom_fields: list[CustomField]) -> list[Li
     return all_list_items
 
 
-def generate_cas_seeds(seed_prefix: str) -> list[Cas]:
+def generate_cas_seeds(
+    seed_prefix: str,
+    static_custom_fields: list[CustomField],
+    static_lists: list[ListItem],
+) -> list[Cas]:
     """
     Generates a list of CAS seed objects for testing without IDs.
 
@@ -153,7 +168,23 @@ def generate_cas_seeds(seed_prefix: str) -> list[Cas]:
     List[Cas]
         A list of Cas objects with different permutations.
     """
+    cas_string_custom_fields = [
+        x
+        for x in static_custom_fields
+        if x.service == ServiceType.CAS and x.field_type == FieldType.STRING
+    ]
+    cas_list_custom_fields = [
+        x
+        for x in static_custom_fields
+        if x.service == ServiceType.CAS and x.field_type == FieldType.LIST
+    ]
 
+    faux_metadata = {}
+    for i, custom_field in enumerate(cas_string_custom_fields):
+        faux_metadata[custom_field.name] = f"{seed_prefix} - {custom_field.display_name} {i}"
+    for i, custom_field in enumerate(cas_list_custom_fields):
+        list_items = [x for x in static_lists if x.list_type == custom_field.name]
+        faux_metadata[custom_field.name] = [list_items[i].to_entity_link()]
     return [
         # CAS with basic fields
         Cas(
@@ -195,6 +226,14 @@ def generate_cas_seeds(seed_prefix: str) -> list[Cas]:
             description="Unknown substance",
             category=CasCategory.UNKNOWN,
         ),
+        # CAS with Metadata
+        Cas(
+            number=f"{seed_prefix}-with-metadata-50-00-0",
+            description="Formaldehyde",
+            category=CasCategory.USER,
+            smiles="C=O",
+            metadata=faux_metadata,
+        ),
     ]
 
 
@@ -325,7 +364,7 @@ def generate_project_seeds(seed_prefix: str, seeded_locations: list[Location]) -
     """
 
     return [
-        # Project with basic metadata and public classification
+        # Project with basic metadata and private classification
         Project(
             description=f"{seed_prefix} - A basic development project.",
             locations=[EntityLink(id=seeded_locations[0].id)],
@@ -335,7 +374,7 @@ def generate_project_seeds(seed_prefix: str, seeded_locations: list[Location]) -
         Project(
             description=f"{seed_prefix} - A public research project focused on new materials.",
             locations=[EntityLink(id=seeded_locations[1].id)],
-            project_class=ProjectClass.PUBLIC,
+            project_class=ProjectClass.SHARED,
             grid=GridDefault.WKS,
         ),
         # Project with production category and custom ACLs
@@ -459,11 +498,35 @@ def generate_data_template_seeds(
     user: User,
     seeded_data_columns: list[DataColumn],
     seeded_units: list[Unit],
+    seeded_tags: list[Tag],
+    seeded_parameters: list[Parameter],
 ) -> list[DataTemplate]:
+    """
+    Generates a list of DataTemplate seed objects for testing with enhanced complexity.
+
+    Parameters
+    ----------
+    seed_prefix : str
+        A prefix for naming the seeds.
+    user : User
+        The user associated with the data templates.
+    seeded_data_columns : list[DataColumn]
+        A list of seeded DataColumn objects.
+    seeded_units : list[Unit]
+        A list of seeded Unit objects.
+    seeded_tags : list[Tag]
+        A list of seeded Tag objects.
+
+    Returns
+    -------
+    list[DataTemplate]
+        A list of DataTemplate objects with enhanced complexity.
+    """
     return [
+        # Basic Data Template with a single column and no validations
         DataTemplate(
             name=f"{seed_prefix} - Basic Data Template",
-            description="A basic data template with no metadata.",
+            description="A basic data template with no validations or tags.",
             data_column_values=[
                 DataColumnValue(
                     data_column=seeded_data_columns[0],
@@ -471,33 +534,225 @@ def generate_data_template_seeds(
                     unit=EntityLink(id=seeded_units[0].id),
                 )
             ],
+            tags=[seeded_tags[0]],
         ),
+        # Data Template with ACL and multiple columns
         DataTemplate(
             name=f"{seed_prefix} - ACL Data Template",
-            description="A basic data template with no metadata.",
+            description="A data template with ACL and multiple columns.",
             data_column_values=[
                 DataColumnValue(
                     data_column=seeded_data_columns[0],
                     value="45.0",
-                    unit=seeded_units[0],
-                )
-            ],
-            users_with_access=[user],
-        ),
-        DataTemplate(
-            name=f"{seed_prefix} - Data Template with Calculations",
-            description="A data template with calculations.",
-            data_column_values=[
-                DataColumnValue(
-                    data_column_id=seeded_data_columns[0].id,
-                    unit=seeded_units[0],
+                    unit=EntityLink(id=seeded_units[0].id),
                 ),
                 DataColumnValue(
                     data_column=seeded_data_columns[1],
-                    calculation=f"={seeded_data_columns[0].name}/2",
-                    unit=seeded_units[0],
+                    value="100.0",
+                    unit=EntityLink(id=seeded_units[1].id),
                 ),
             ],
+            users_with_access=[user],
+        ),
+        # Data Template with ENUM validation and tags
+        DataTemplate(
+            name=f"{seed_prefix} - Enum Validation Template",
+            description="A data template with enum validation and tags.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[0],
+                    value="Option1",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="Option1"),
+                                EnumValidationValue(text="Option2"),
+                            ],
+                        )
+                    ],
+                )
+            ],
+            tags=seeded_tags[:2],
+        ),
+        # Data Template with NUMBER validation and a calculation
+        DataTemplate(
+            name=f"{seed_prefix} - Number Validation Template",
+            description="A data template with number validation and a calculation.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[1],
+                    value="50",
+                    unit=EntityLink(id=seeded_units[0].id),
+                    calculation="Pressure = Force / Area",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="0",
+                            max="100",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                )
+            ],
+            tags=[seeded_tags[1], seeded_tags[2]],
+        ),
+        # Data Template with STRING validation
+        DataTemplate(
+            name=f"{seed_prefix} - String Validation Template",
+            description="A data template with string validation.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[2],
+                    value="Test String",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.STRING,
+                        )
+                    ],
+                )
+            ],
+        ),
+        # Data Template with multiple validations and tags
+        DataTemplate(
+            name=f"{seed_prefix} - Complex Validation Template",
+            description="A data template with multiple validations and tags.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[0],
+                    value="Option1",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="Option1"),
+                                EnumValidationValue(text="Option2"),
+                            ],
+                        )
+                    ],
+                ),
+                DataColumnValue(
+                    data_column=seeded_data_columns[1],
+                    value="75.0",
+                    unit=EntityLink(id=seeded_units[1].id),
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="50",
+                            max="100",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                ),
+            ],
+            tags=[seeded_tags[0]],
+        ),
+        # Data Template with calculations and no validations
+        DataTemplate(
+            name=f"{seed_prefix} - Calculation Template",
+            description="A data template with calculations and no validations.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[0],
+                    calculation="=A1 + B1",
+                    unit=EntityLink(id=seeded_units[0].id),
+                ),
+                DataColumnValue(
+                    data_column=seeded_data_columns[1],
+                    calculation="=C1 / 2",
+                    unit=EntityLink(id=seeded_units[1].id),
+                ),
+            ],
+        ),
+        # Data Template with parameters (for PATCH /parameters testing)
+        DataTemplate(
+            name=f"{seed_prefix} - Parameters Data Template",
+            description="A data template with parameters for testing PATCH /parameters.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[0],
+                    value="42.0",
+                    unit=EntityLink(id=seeded_units[0].id),
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="0",
+                            max="100",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                )
+            ],
+            parameter_values=[
+                ParameterValue(
+                    id=seeded_parameters[
+                        0
+                    ].id,  # Replace with a valid seeded Parameter id if available
+                    name="Test Parameter",
+                    value="123.45",
+                    unit=EntityLink(id=seeded_units[0].id),
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="0",
+                            max="200",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                )
+            ],
+            tags=[seeded_tags[0]],
+        ),
+        # Data Template with ENUM validations on both a data column and a parameter
+        DataTemplate(
+            name=f"{seed_prefix} - Enum Validation Data Template With Parameter",
+            description="A data template with ENUM validations on both a data column and a parameter.",
+            data_column_values=[
+                DataColumnValue(
+                    data_column=seeded_data_columns[1],
+                    value="OptionA",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="OptionA"),
+                                EnumValidationValue(text="OptionB"),
+                            ],
+                        )
+                    ],
+                )
+            ],
+            parameter_values=[
+                ParameterValue(
+                    id=seeded_parameters[2].id,
+                    name="Enum Parameter",
+                    value="ParamOption1",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="ParamOption1"),
+                                EnumValidationValue(text="ParamOption2"),
+                            ],
+                        )
+                    ],
+                ),
+                ParameterValue(
+                    id=seeded_parameters[3].id,
+                    name="Enum Parameter two",
+                    value="ParamOption1-1",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="ParamOption1-1"),
+                                EnumValidationValue(text="ParamOption1-2"),
+                            ],
+                        )
+                    ],
+                ),
+            ],
+            tags=[seeded_tags[1]],
         ),
     ]
 
@@ -584,9 +839,103 @@ def generate_parameter_group_seeds(
                 )
             ],
         ),
-        # ParameterGroup with all fields filled out
         ParameterGroup(
-            name=f"{seed_prefix} - Batch Parameters",
+            name=f"{seed_prefix} - Enums Parameter Group",
+            type=PGType.GENERAL,
+            description="A general parameter group with validations and tags.",
+            parameters=[
+                ParameterValue(
+                    parameter=seeded_parameters[0],
+                    value="10",
+                    unit=EntityLink(id=seeded_units[0].id),
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="0",
+                            max="100",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                ),
+                ParameterValue(
+                    parameter=seeded_parameters[2],
+                    value="500.0",
+                    unit=seeded_units[2],
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            operator=Operator.GREATER_THAN_OR_EQUAL,
+                            value="0.0",
+                        )
+                    ],
+                ),
+                ParameterValue(
+                    parameter=seeded_parameters[1],
+                    value="Option1",
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.ENUM,
+                            value=[
+                                EnumValidationValue(text="Option1"),
+                                EnumValidationValue(text="Option2"),
+                            ],
+                        )
+                    ],
+                ),
+            ],
+            tags=seeded_tags[:2],
+        ),
+        ParameterGroup(
+            name=f"{seed_prefix} - Numbers Parameter Group",
+            type=PGType.GENERAL,
+            description="A general parameter group with validations and tags.",
+            parameters=[
+                ParameterValue(
+                    parameter=seeded_parameters[0],
+                    value="10",
+                    unit=EntityLink(id=seeded_units[0].id),
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            min="0",
+                            max="100",
+                            operator=Operator.BETWEEN,
+                        )
+                    ],
+                ),
+                ParameterValue(
+                    parameter=static_consumeable_parameter, category=ParameterCategory.SPECIAL
+                ),
+                ParameterValue(
+                    parameter=seeded_parameters[2],
+                    value="500.0",
+                    unit=seeded_units[2],
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            operator=Operator.GREATER_THAN_OR_EQUAL,
+                            value="0.0",
+                        )
+                    ],
+                ),
+            ],
+            tags=seeded_tags[:2],
+        ),
+        ParameterGroup(
+            name=f"{seed_prefix} - Batch Parameter Group",
+            type=PGType.BATCH,
+            description="A batch parameter group with no validations.",
+            parameters=[
+                ParameterValue(
+                    parameter=seeded_parameters[1],
+                    value="Test Value",
+                    unit=EntityLink(id=seeded_units[1].id),
+                )
+            ],
+            tags=seeded_tags[2:],
+        ),
+        ParameterGroup(
+            name=f"{seed_prefix} - Batch Parameters with a consumeable",
             description="Parameters for batch processing",
             type=PGType.BATCH,
             security_class=SecurityClass.RESTRICTED,
@@ -600,6 +949,13 @@ def generate_parameter_group_seeds(
                     parameter=seeded_parameters[2],
                     value="500.0",
                     unit=seeded_units[2],
+                    validation=[
+                        ValueValidation(
+                            datatype=DataType.NUMBER,
+                            operator=Operator.GREATER_THAN_OR_EQUAL,
+                            value="0.0",
+                        )
+                    ],
                 ),
                 ParameterValue(
                     parameter=static_consumeable_parameter, category=ParameterCategory.SPECIAL
@@ -609,7 +965,7 @@ def generate_parameter_group_seeds(
         ),
         # ParameterGroup with no tags or metadata
         ParameterGroup(
-            name=f"{seed_prefix} - Property Parameters",
+            name=f"{seed_prefix} - Simple Property Parameters",
             type=PGType.PROPERTY,
             parameters=[
                 ParameterValue(
@@ -817,17 +1173,20 @@ def generate_workflow_seeds(
     consumeable_inv = [x for x in seeded_inventory if x.category == InventoryCategory.CONSUMABLES][
         0
     ]
+    pg0 = seeded_parameter_groups[0]
+    pg2 = seeded_parameter_groups[2]
+
     return [
         Workflow(
             name=f"{seed_prefix} - Workflow 1",
             parameter_group_setpoints=[
                 ParameterGroupSetpoints(
-                    parameter_group=seeded_parameter_groups[0],
+                    parameter_group=pg0,
                     parameter_setpoints=[
                         ParameterSetpoint(
-                            parameter_id=seeded_parameter_groups[0].parameters[0].id,
+                            parameter_id=pg0.parameters[0].id,
                             value="25.0",
-                            unit=seeded_parameter_groups[0].parameters[0].unit,
+                            unit=pg0.parameters[0].unit,
                         ),
                     ],
                 )
@@ -837,12 +1196,12 @@ def generate_workflow_seeds(
             name=f"{seed_prefix} - Workflow 2 Equipment",
             parameter_group_setpoints=[
                 ParameterGroupSetpoints(
-                    parameter_group=seeded_parameter_groups[1],
+                    parameter_group=pg2,
                     parameter_setpoints=[
                         ParameterSetpoint(
-                            parameter_id=seeded_parameter_groups[1].parameters[0].id,
+                            parameter_id=pg2.parameters[0].id,
                             value="25.0",
-                            unit=seeded_parameter_groups[1].parameters[0].unit,
+                            unit=pg2.parameters[0].unit,
                         ),
                         ParameterSetpoint(
                             parameter_id=static_consumeable_parameter.id,
@@ -851,16 +1210,10 @@ def generate_workflow_seeds(
                             category=ParameterCategory.SPECIAL,
                         ),
                         ParameterSetpoint(
-                            parameter=_get_param_from_id(
-                                seeded_parameters, seeded_parameter_groups[1].parameters[1].id
-                            ),  # Make sure setting from the parameter works
+                            parameter=_get_param_from_id(seeded_parameters, pg2.parameters[2].id),
                             intervals=[
-                                Interval(
-                                    value="1.1", unit=seeded_parameter_groups[1].parameters[1].unit
-                                ),
-                                Interval(
-                                    value="2.2", unit=seeded_parameter_groups[1].parameters[1].unit
-                                ),
+                                Interval(value="1.1", unit=pg2.parameters[2].unit),
+                                Interval(value="2.2", unit=pg2.parameters[2].unit),
                             ],
                         ),
                     ],
@@ -871,25 +1224,19 @@ def generate_workflow_seeds(
             name=f"{seed_prefix} - Workflow 3",
             parameter_group_setpoints=[
                 ParameterGroupSetpoints(
-                    parameter_group=seeded_parameter_groups[2],
+                    parameter_group=pg2,
                     parameter_setpoints=[
                         ParameterSetpoint(
-                            parameter=_get_param_from_id(
-                                seeded_parameters, seeded_parameter_groups[2].parameters[1].id
-                            ),  # make sure setting from a parameter works
+                            parameter=_get_param_from_id(seeded_parameters, pg2.parameters[0].id),
                             value="12.2",
-                            unit=seeded_parameter_groups[2].parameters[1].unit,
-                            categoty=ParameterCategory.NORMAL,
+                            unit=pg2.parameters[0].unit,
+                            category=ParameterCategory.NORMAL,
                         ),
                         ParameterSetpoint(
-                            parameter_id=seeded_parameter_groups[2].parameters[0].id,
+                            parameter_id=pg2.parameters[1].id,
                             intervals=[
-                                Interval(
-                                    value="1.1", unit=seeded_parameter_groups[2].parameters[0].unit
-                                ),
-                                Interval(
-                                    value="2.2", unit=seeded_parameter_groups[2].parameters[0].unit
-                                ),
+                                Interval(value="1.1", unit=pg2.parameters[0].unit),
+                                Interval(value="2.2", unit=pg2.parameters[0].unit),
                             ],
                         ),
                     ],
@@ -1009,7 +1356,7 @@ def generate_task_seeds(
             name=f"{seed_prefix} - Property Task 1",
             category=TaskCategory.PROPERTY,
             inventory_information=[
-                InventoryInformation(
+                TaskInventoryInformation(
                     inventory_id=seeded_inventory[0].id,
                     lot_id=seeded_lots[0].id,
                 )
@@ -1032,7 +1379,7 @@ def generate_task_seeds(
             name=f"{seed_prefix} - Property Task 2",
             category=TaskCategory.PROPERTY,
             inventory_information=[
-                InventoryInformation(
+                TaskInventoryInformation(
                     inventory_id=seeded_inventory[1].id,
                     lot_id=(
                         [l for l in seeded_lots if l.inventory_id == seeded_inventory[1].id][0].id
@@ -1054,7 +1401,7 @@ def generate_task_seeds(
             name=f"{seed_prefix} - General Task with metadata",
             category=TaskCategory.GENERAL,
             inventory_information=[
-                InventoryInformation(
+                TaskInventoryInformation(
                     inventory_id=seeded_inventory[2].id,
                 )
             ],
@@ -1070,7 +1417,7 @@ def generate_task_seeds(
             category=TaskCategory.BATCH,
             batch_size_unit=BatchSizeUnit.KILOGRAMS,
             inventory_information=[
-                InventoryInformation(
+                TaskInventoryInformation(
                     inventory_id=seeded_products[2].id,
                     batch_size=100.0,
                 )
@@ -1090,7 +1437,7 @@ def generate_task_seeds(
             category=TaskCategory.BATCH,
             batch_size_unit=BatchSizeUnit.GRAMS,
             inventory_information=[
-                InventoryInformation(
+                TaskInventoryInformation(
                     inventory_id=seeded_products[1].id,
                     batch_size=250.0,
                 )
@@ -1143,7 +1490,7 @@ def generate_btdataset_seed(seed_prefix: str) -> BTDataset:
 def generate_btmodelsession_seed(seed_prefix: str, seeded_btdataset: BTDataset) -> BTModelSession:
     return BTModelSession(
         name=f"{seed_prefix} - Test BT Model Session",
-        category=BTModelCategory.ALBERT_MODEL,
+        category=BTModelSessionCategory.ALBERT_MODEL,
         dataset_id=seeded_btdataset.id,
     )
 
@@ -1160,7 +1507,7 @@ def generate_btmodel_seed(seed_prefix: str, seeded_btdataset: BTDataset) -> BTMo
 def generate_btinsight_seed(
     seed_prefix: str,
     seeded_btdataset: BTDataset,
-    seeded_btmodelsession: BTModelSession,
+    seeded_btmodelsession: BTModel,
 ) -> BTInsight:
     return BTInsight(
         name=f"{seed_prefix} - Test BT Insight",
@@ -1169,3 +1516,35 @@ def generate_btinsight_seed(
         category=BTInsightCategory.CUSTOM_OPTIMIZER,
         metadata={},
     )
+
+
+def generate_report_seeds(
+    seed_prefix: str, seeded_projects: list[Project]
+) -> list[FullAnalyticalReport]:
+    """
+    Generates a list of FullAnalyticalReport seed objects for testing.
+
+    Parameters
+    ----------
+    seed_prefix : str
+        Prefix to use for generating unique names.
+    seeded_projects : list[Project]
+        List of seeded Project objects to reference in reports.
+
+    Returns
+    -------
+    list[FullAnalyticalReport]
+        A list of FullAnalyticalReport objects with different configurations.
+    """
+    project_ids = [project.id for project in seeded_projects]
+
+    return [
+        # Basic analytical report
+        FullAnalyticalReport(
+            report_type_id="ALB#RET42",
+            name=f"{seed_prefix} - Basic Analytical Report",
+            description=f"{seed_prefix} - A basic analytical report for testing",
+            input_data={"project": project_ids},
+            project_id=seeded_projects[0].id if seeded_projects else None,
+        ),
+    ]
